@@ -16,7 +16,7 @@ _get_ves()
 			[ -n "$veids" ] || veids=100
 			echo $((veids+1))
 			;;
-		start|mount|umount|destroy|delete)
+		start|mount|umount|destroy|delete|convert)
 			# stopped CTs
 			/usr/sbin/vzlist -H -S -octid 2>/dev/null
 			/usr/sbin/vzlist -H -S -oname 2>/dev/null | $rm_empty
@@ -56,9 +56,11 @@ _vzctl()
 	local vzctl_common_opts="--quiet --verbose --help --version"
 	local vzctl_cmds="create destroy delete mount umount chkpnt restore \
 		set start stop restart status quotaon quotaoff quotainit \
-		enter exec exec2 runscript"
+		enter exec exec2 runscript convert console \
+		snapshot snapshot-switch snapshot-delete snapshot-list"
 	local vzctl_create_opts="--ostemplate --config --private --root \
-		--ipadd --hostname --name --description"
+		--layout --diskspace --ipadd --hostname --name --description"
+	local vzctl_convert_opts="--layout"
 	local vzctl_set_opts="--save --onboot --root --private \
 		--userpasswd --disabled --ipadd --ipdel \
 		--hostname --nameserver --searchdomain \
@@ -76,6 +78,7 @@ _vzctl()
 	local vzctl_start_opts="--wait --force"
 	local vzctl_stop_opts="--fast"
 	local vzctl_restart_opts="$vzctl_start_opts $vzctl_stop_opts"
+	local vzctl_snapshot_create_opts="--id --name --description"
 
 	local iptables_names="iptable_filter iptable_mangle ipt_limit
 		ipt_multiport ipt_tos ipt_TOS ipt_REJECT ipt_TCPMSS
@@ -142,6 +145,9 @@ _vzctl()
 
 				COMPREPLY=( $( compgen -W "$configs" -- $cur ) )
 				;;
+			--layout)
+				COMPREPLY=( $( compgen -W "ploop ploop:expanded ploop:plain ploop:raw simfs" -- $cur ) )
+				;;
 			--iptables)
 				COMPREPLY=( $( compgen -W "$iptables_names" -- $cur ) )
 				;;
@@ -246,6 +252,9 @@ _vzctl()
 					set)
 						COMPREPLY=( $( compgen -W "$vzctl_set_opts" -- $cur ) )
 						;;
+					convert)
+						COMPREPLY=( $( compgen -W "$vzctl_convert_opts" -- $cur ) )
+						;;
 					chkpnt|restore)
 						COMPREPLY=( $( compgen -W "--dumpfile" -- $cur ) )
 						;;
@@ -258,6 +267,12 @@ _vzctl()
 					restart)
 						COMPREPLY=( $( compgen -W "$vzctl_restart_opts" -- $cur ) )
 						;;
+					snapshot|snapshot-create)
+						COMPREPLY=( $( compgen -W "$vzctl_snapshot_create_opts" -- $cur ) )
+						;;
+					snapshot-switch|snapshot-delete)
+						COMPREPLY=( $( compgen -W "--id" -- $cur ) )
+						;;
 					*)
 						;;
 					esac
